#!/usr/bin/env python
# Licensed to PSF under a Contributor Agreement.
# See http://www.python.org/psf/license for licensing details.

__author__  = "Sorin Sbarnea"
__copyright__ = "Copyright 2010-2012, Sorin Sbarnea"
__email__   = "sorindotsbarnea@gmail.com"
__status__  = "Development"
__version__ = "0.0.13"
__date__    = "2012-06-20"

__all__ = ['tee','colorer','unicode','execfile2','singleton']

"""
	Tendo is tested with Python 2.5-3.2
"""

import sys
if sys.hexversion < 0x02050000:
	sys.exit("Python 2.5 or newer is required by tendo module.")



#!/usr/bin/env python
# encoding: utf-8
# Author: sorin sbarnea
# License: public domain

"""
Colorer does enable colored logging messages by using `ANSI escape sequences <http://en.wikipedia.org/wiki/ANSI_escape_code>`_.

Under Windows, where the escapes are not supported it does use the Windows API.

The colored output is generated only when the console is a terminal supporting it, so if you redirect the output to a log file you will not see the escape codes in the file.

>>> import colorer, logging
... logging.error("red line")
... logging.warn("yellow line")
... logging.info("gray line")
... logging.debug("magenta line")
"""
import logging, sys, os

if (hasattr(sys.stderr, "isatty") and sys.stderr.isatty()) or ('TERM' in os.environ.keys() and os.environ['TERM'] in ['linux'] ):
	# Why stderr and not stdout? - because python logging module does output to stderr by default and not stdout.
	# now we patch Python code to add color support to logging.StreamHandler
	def add_coloring_to_emit_windows(fn):
			# add methods we need to the class
		def _out_handle(self):
			import ctypes
			return ctypes.windll.kernel32.GetStdHandle(self.STD_OUTPUT_HANDLE)

		def _set_color(self, code):
			import ctypes
			# Constants from the Windows API
			self.STD_OUTPUT_HANDLE = -11
			hdl = ctypes.windll.kernel32.GetStdHandle(self.STD_OUTPUT_HANDLE)
			ctypes.windll.kernel32.SetConsoleTextAttribute(hdl, code)

		setattr(logging.StreamHandler, '_set_color', _set_color)

		def new(*args):
			FOREGROUND_BLUE      = 0x0001 # text color contains blue.
			FOREGROUND_GREEN     = 0x0002 # text color contains green.
			FOREGROUND_RED       = 0x0004 # text color contains red.
			FOREGROUND_INTENSITY = 0x0008 # text color is intensified.
			FOREGROUND_WHITE     = FOREGROUND_BLUE|FOREGROUND_GREEN |FOREGROUND_RED
			# winbase.h
			STD_INPUT_HANDLE = -10
			STD_OUTPUT_HANDLE = -11
			STD_ERROR_HANDLE = -12

			# wincon.h
			FOREGROUND_BLACK     = 0x0000
			FOREGROUND_BLUE      = 0x0001
			FOREGROUND_GREEN     = 0x0002
			FOREGROUND_CYAN      = 0x0003
			FOREGROUND_RED       = 0x0004
			FOREGROUND_MAGENTA   = 0x0005
			FOREGROUND_YELLOW    = 0x0006
			FOREGROUND_GREY      = 0x0007
			FOREGROUND_INTENSITY = 0x0008 # foreground color is intensified.

			BACKGROUND_BLACK     = 0x0000
			BACKGROUND_BLUE      = 0x0010
			BACKGROUND_GREEN     = 0x0020
			BACKGROUND_CYAN      = 0x0030
			BACKGROUND_RED       = 0x0040
			BACKGROUND_MAGENTA   = 0x0050
			BACKGROUND_YELLOW    = 0x0060
			BACKGROUND_GREY      = 0x0070
			BACKGROUND_INTENSITY = 0x0080 # background color is intensified.     

			levelno = args[1].levelno
			if levelno>=50:
				color = BACKGROUND_YELLOW | FOREGROUND_RED | FOREGROUND_INTENSITY | BACKGROUND_INTENSITY 
			elif levelno>=40:
				color = FOREGROUND_RED | FOREGROUND_INTENSITY
			elif levelno>=30:
				color = FOREGROUND_YELLOW | FOREGROUND_INTENSITY
			elif levelno>=20:
				color = FOREGROUND_GREEN
			elif levelno>=10:
				color = FOREGROUND_MAGENTA
			else:
				color =  FOREGROUND_WHITE
			args[0]._set_color(color)

			ret = fn(*args)
			args[0]._set_color( FOREGROUND_WHITE )
			#print "after"
			return ret
		return new

	def add_coloring_to_emit_ansi(fn):
		# add methods we need to the class
		def new(*args):
			levelno = args[1].levelno
			if levelno>=50:
				color = '\x1b[31m' # red
			elif levelno>=40 :
				color = '\x1b[31m' # red
			elif levelno>=30 :
				color = '\x1b[33m' # yellow
			elif levelno>=20 :
				color = '\x1b[32m' # green 
			elif levelno>=10:
				color = '\x1b[35m' # pink
			else:
				color = '\x1b[0m' # normal
			args[1].msg = color + str(args[1].msg) +  '\x1b[0m'  # normal
			#print "after"
			return fn(*args)
		return new

	import platform
	if platform.system()=='Windows':
		# Windows does not support ANSI escapes and we are using API calls to set the console color
		logging.StreamHandler.emit = add_coloring_to_emit_windows(logging.StreamHandler.emit)
	else:
		# all non-Windows platforms are supporting ANSI escapes so we use them
		logging.StreamHandler.emit = add_coloring_to_emit_ansi(logging.StreamHandler.emit)
		#log = logging.getLogger()
		#log.addFilter(log_filter())
		#//hdlr = logging.StreamHandler()
		#//hdlr.setFormatter(formatter())

if __name__ == '__main__':
	import logging
	# import colorer
	# remember that logging outputs to stderr and not stdout (just in case you'll wonder)

	for param in os.environ.keys():
		print("%25s %s" % (param,os.environ[param]))

	isatty = None
	if hasattr(sys.stderr, "isatty"):
		isatty = sys.stderr.isatty()
	print("sys.stderr.isatty = %s" % isatty)

	isatty = None
	if hasattr(sys.stdout, "isatty"):
		isatty = sys.stdout.isatty()
	print("sys.stdout.isatty = %s" % isatty)

	logging.getLogger().setLevel(logging.NOTSET)
	logging.warn("a warning")
	logging.error("some error")
	logging.info("some info")
	logging.debug("some info")



#!/usr/bin/python
import codecs, sys, unittest, logging, tempfile, os
import six
"""
Author: Sorin Sbarnea

This file does add some additional Unicode support to Python, like:
* auto-detect BOM on text-file open: open(file, "r") and open(file, "rU")

"""
# we save the file function handler because we want to override it
open_old = open

def open(filename, mode='r', bufsize=-1, fallback_encoding='utf_8'):
		"""
		This replaces Python original open() function with an improved version that is Unicode aware.

		The new `open()` does change behaviour only for text files, not binary.
		
		* mode is by default 'r' if not specified and text mode
		* negative bufsize makes it use the default system one (same as not specified)

		>>> import tendo.unicode
		... f = open("file-with-unicode-content.txt")
		... content = f.read() # Unicode content of the file, without BOM

		Shortly by importing unicode, you will repair code that previously was broken when the input files were Unicode.

		This will not change the behavior of  code that reads the files as binary, it has an effect on text file operations.

		Files with BOM will be read properly as Unicode and the BOM will not be part of the text.

		If you do not specify the fallback_encoding, files without BOM will be read as `UTF-8` instead of `ascii`.

		"""
		# Do not assign None to bufsize or mode because calling original open will fail

		# we read the first 4 bytes just to be sure we use the right encoding
		if "r" in mode or "a" in mode: # we are interested of detecting the mode only for read text
			try:
				f = open_old(filename, "rb")
				aBuf = bytes(f.read(4))
				f.close()
			except:
				aBuf=six.b('')
			if six.binary_type(aBuf[:3]) ==   six.b('\xEF\xBB\xBF') :
				f = codecs.open(filename, mode, "utf_8")
				f.seek(3,0)
				f.BOM = codecs.BOM_UTF8
			elif six.binary_type(aBuf[:2]) == six.b('\xFF\xFE'):
				f = codecs.open(filename, mode, "utf_16_le")
				f.seek(2,0)
				f.BOM = codecs.BOM_UTF16_LE
			elif six.binary_type(aBuf[:2]) == six.b('\xFE\xFF'):
				f = codecs.open(filename, mode, "utf_16_be")
				f.seek(2,0)
				f.BOM = codecs.BOM_UTF16_BE
			elif six.binary_type(aBuf[:4]) == six.b('\xFF\xFE\x00\x00'):
				f = codecs.open(filename, mode, "utf_32_le")
				f.seek(4,0)
				f.BOM = codecs.BOM_UTF32_LE
			elif six.binary_type(aBuf[:4]) == six.b('\x00\x00\xFE\xFF'):
				f = codecs.open(filename, mode, "utf_32_be")
				f.seek(4,0)
				f.BOM = codecs.BOM_UTF32_BE
			else:  # we assume that if there is no BOM, the encoding is UTF-8
				f = codecs.open(filename, mode, fallback_encoding)
				f.seek(0)
				f.BOM = None
			return f
		else:
			import traceback
			logging.warning("Calling unicode.open(%s,%s,%s) that may be wrong." % (filename, mode, bufsize))
			traceback.print_exc(file=sys.stderr)
			
			return open_old(filename, mode, bufsize)

class testUnicode(unittest.TestCase):
	def setUp(self):
		os.chdir(os.path.dirname(os.path.abspath(__file__)))

	def test_read_utf8(self):
		try:
			f = open("tests/utf8.txt","rU")
			f.readlines()
			f.close()
		except Exception:
			type, e, tb = sys.exc_info()
			self.assertTrue(False, "Unable to properly read valid utf8 encoded file: " + e)

	def test_read_invalid_utf8(self):
		passed = False
		try:
			f = open("tests/utf8-invalid.txt","rU")
			f.readlines()
			f.close()
		except Exception:
			type, e, tb = sys.exc_info()
			if isinstance(e, UnicodeDecodeError):
				passed = True # yes, we expect an exception
			pass
		self.assertTrue(passed, "Unable to detect invalid utf8 file")		

	def test_write_on_existing_utf8(self):
		import shutil, filecmp, os
		(ftmp, fname_tmp) = tempfile.mkstemp()
		shutil.copyfile("tests/utf8.txt", fname_tmp)
		f = open(fname_tmp,"a") # encoding not specified, should use utf-8
		f.write(six.u("\u0061\u0062\u0063\u0219\u021B\u005F\u1E69\u0073\u0323\u0307\u0073\u0307\u0323\u005F\u0431\u0434\u0436\u005F\u03B1\u03B2\u03CE\u005F\u0648\u062A\u005F\u05D0\u05E1\u05DC\u005F\u6C38\U0002A6A5\u9EB5\U00020000"))
		f.close()
		passed = filecmp.cmp("tests/utf8-after-append.txt", fname_tmp, shallow=False)
		self.assertTrue(passed, "Appending to existing UTF-8 file test failed (%s)." % fname_tmp)
		os.close(ftmp)
		os.unlink(fname_tmp)


if __name__ == '__main__':
	unittest.main()

	#lines = open("test/utf8.txt","rU")
	
	#for line in lines:
	#	print(line)




#! /usr/bin/env python

import sys, os, errno, tempfile, unittest, logging
from multiprocessing import Process

class SingleInstance:
	"""
	If you want to prevent your script from running in parallel just instantiate SingleInstance() class. If is there another instance already running it will exist the application with the message "Another instance is already running, quitting.", returning -1 error code.

	>>> import tendo
	... me = SingleInstance()

	This option is very useful if you have scripts executed by crontab at small amounts of time.

	Remember that this works by creating a lock file with a filename based on the full path to the script file.
	"""
	def __init__(self, flavor_id=""):
		import sys
		self.lockfile = os.path.normpath(tempfile.gettempdir() + '/' +
		    os.path.splitext(os.path.abspath(sys.modules['__main__'].__file__))[0].replace("/","-").replace(":","").replace("\\","-")  + '-%s' % flavor_id +'.lock')
		logger.debug("SingleInstance lockfile: " + self.lockfile)
		if sys.platform == 'win32':
			try:
				# file already exists, we try to remove (in case previous execution was interrupted)
				if os.path.exists(self.lockfile):
					os.unlink(self.lockfile)
				self.fd =  os.open(self.lockfile, os.O_CREAT|os.O_EXCL|os.O_RDWR)
			except OSError:
				type, e, tb = sys.exc_info()
				if e.errno == 13:
					logger.error("Another instance is already running, quitting.")
					sys.exit(-1)
				print(e.errno)
				raise
		else: # non Windows
			import fcntl, sys
			self.fp = open(self.lockfile, 'w')
			try:
				fcntl.lockf(self.fp, fcntl.LOCK_EX | fcntl.LOCK_NB)
			except IOError:
				logger.warning("Another instance is already running, quitting.")
				sys.exit(-1)

	def __del__(self):
		import sys
		if sys.platform == 'win32':
			if hasattr(self, 'fd'):
				os.close(self.fd)
				os.unlink(self.lockfile)

def f():
	tmp = logger.level
	logger.setLevel(logging.CRITICAL) # we do not want to see the warning
	me2 = SingleInstance()
	logger.setLevel(tmp)
	pass

class testSingleton(unittest.TestCase):
	def test_1(self):
		me = SingleInstance()
		pass
	def test_2(self):
		p = Process(target=f)
		p.start()
		p.join()
		assert  p.exitcode == 0, "%s != 0" % p.exitcode # the called function should succeed
	def test_3(self):
		me = SingleInstance()
		p = Process(target=f)
		p.start()
		p.join()
		assert  p.exitcode != 0, "%s != 0" % p.exitcode # the called function should fail because we already have another instance running
		# note, we return -1 but this translates to 255 meanwhile we'll consider that anything different from 0 is good

logger = logging.getLogger("tendo.singleton")
logger.addHandler(logging.StreamHandler())

if __name__ == "__main__":
	logger.setLevel(logging.DEBUG)
	unittest.main()




#!/usr/bin/env python
import os, sys, unittest, tempfile, shlex

if sys.hexversion > 0x03000000:
	def execfile(file, globals=globals(), locals=locals()):
		fh = open(file, "r")
		if not fh: raise Exception("Unable to open %s." % file)
		exec(fh.read()+"\n", globals, locals)
		# The code below is not parsed by python2.5
		#with open(file, "r") as fh:
		#	exec(fh.read()+"\n", globals, locals)

def execfile2(filename, _globals=dict(), _locals=dict(), cmd=None, quiet=False):
	"""
	Execute a Python script using :py:func:`execfile`.
	In addition to Python :py:func:`execfile` this method can temporary change the argv params.

	This enables you to call an external python script that requires
	command line arguments without leaving current python interpretor.

	`cmd` can be a string with command line arguments or a list or arguments

	The return value is a numeric exit code similar to the one used for command line tools:

	- 0 - if succesfull; this applies if script receives SystemExit with error code 0
	- 1 - if SystemExit does not contain an error code or if other Exception is received.
	- x - the SystemExit error code (if present)

	"""
	_globals['__name__']='__main__'
	saved_argv = sys.argv # we save sys.argv
	if cmd:
		sys.argv=list([filename])
		if isinstance(cmd , list):
			sys.argv.append(cmd)
		else:
			sys.argv.extend(shlex.split(cmd))
	exit_code = 0
	try:
		execfile(filename, _globals, _locals)
		
	except SystemExit:
		type, e, tb = sys.exc_info()
		if isinstance(e.code , int):
			exit_code = e.code # this could be 0 if you do sys.exit(0)
		else:
			exit_code = 1
	except Exception:
		if not quiet:
			import traceback
			traceback.print_exc(file=sys.stderr)
		exit_code = 1
	finally:
		if cmd:
			sys.argv = saved_argv # we restore sys.argv
	return exit_code

class testExecfile(unittest.TestCase):
	def _exec_py_code(self, code, cmd=None):
		(ftmp, fname_tmp) = tempfile.mkstemp()
		f = open(fname_tmp,"w") # encoding not specified, should use utf-8
		f.write(code)
		f.close()
		exit_code = execfile2(fname_tmp, cmd=cmd, quiet=True)
		os.close(ftmp)
		os.unlink(fname_tmp)
		return exit_code

	def test_normal_execution(self):
		exit_code = self._exec_py_code("")
		self.assertTrue(exit_code==0)

	def test_bad_code(self):
		exit_code = self._exec_py_code("bleah")
		self.assertTrue(exit_code==1)

	def test_sys_exit_0(self):
		exit_code = self._exec_py_code("import sys; sys.exit(0)")
		self.assertTrue(exit_code==0)

	def test_sys_exit_5(self):
		exit_code = self._exec_py_code("import sys; sys.exit(5)")
		self.assertTrue(exit_code==5)

	def test_sys_exit_text(self):
		exit_code = self._exec_py_code("import sys; sys.exit('bleah')")
		self.assertTrue(exit_code==1)

	def test_raised_exception(self):
		exit_code = self._exec_py_code("raise Exception('bleah')")
		self.assertTrue(exit_code==1)

	def test_command_line(self):
		exit_code = self._exec_py_code("import sys\nif len(sys.argv)==2 and sys.argv[1]=='doh!': sys.exit(-1)", cmd="doh!")
		self.assertTrue(exit_code==-1)

if __name__ == "__main__":
	unittest.main()



#!/usr/bin/env python
# encoding: utf-8
# Author: sorin sbarnea
# License: public domain
import codecs
import functools
import logging
import os
import sys
import subprocess
import types
import time
import unittest

if sys.version_info[0] == 3:
    string_types = str,
else:
    string_types = basestring,

global logger
global stdout
global stderr
global timing
global log_command

logger = None
stdout = False
stderr = False
timing = True # print execution time of each command in the log, just after the return code
log_command = True # outputs the command being executed to the log (before command output)
_sentinel = object()


def quote_command(cmd):
    """
    This function does assure that the command line is entirely quoted.
    This is required in order to prevent getting "The input line is too long" error message.
    """
    if not (os.name == "nt" or os.name == "dos"):
        return cmd # the escaping is required only on Windows platforms, in fact it will break cmd line on others
    if '"' in cmd[1:-1]:
        cmd =  '"' + cmd + '"'
    return cmd

def system2(cmd, cwd=None, logger=_sentinel, stdout=_sentinel, log_command=_sentinel, timing=_sentinel):
    #def tee(cmd, cwd=None, logger=tee_logger, console=tee_console):
    """ Works exactly like :func:`system` but it returns both the exit code and the output as a list of lines.

    This method returns a tuple: (return_code, output_lines_as_list). The return code of 0 means success.
    """
    t = time.clock()
    output = []
    if log_command is _sentinel: log_command = globals().get('log_command')
    if timing is _sentinel: timing = globals().get('timing')

    if logger is _sentinel: # default to python native logger if logger parameter is not used
        logger = globals().get('logger')
    if stdout is _sentinel:
        stdout = globals().get('stdout')

    #logging.debug("logger=%s stdout=%s" % (logger, stdout))

    f = sys.stdout
    if not f.encoding or f.encoding == 'ascii':
    # `ascii` is not a valid encoding by our standards, it's better to output to UTF-8 because it can encoding any Unicode text
        encoding = 'utf_8'
    else:
        encoding = f.encoding

    def filelogger(msg):
        try:
            msg += '\n'  # we'll use the same endline on all platforms, you like it or not
            try:
                f.write(msg)
            except TypeError:
                f.write(msg.encode("utf-8"))
        except Exception:
            type, e, tb = sys.exc_info()
            import traceback
            print('        ****** ERROR: Exception: %s\nencoding = %s' % (e, encoding))
            traceback.print_exc(file=sys.stderr)
            sys.exit(-1)
        pass

    def nop(msg):
        pass

    if not logger:
        mylogger = nop
    elif isinstance(logger, string_types):
        f = codecs.open(logger, "a+b", 'utf_8')
        mylogger = filelogger
    elif isinstance(logger, (types.FunctionType, types.MethodType, types.BuiltinFunctionType)):
        mylogger = logger
    else:
        method_write = getattr(logger, "write", None)
        # if we can call write() we'll aceppt it :D
        if hasattr(method_write,'__call__'): # this should work for filehandles
            f = logger
            mylogger = filelogger
        else:
            sys.exit("tee() does not support this type of logger=%s" % type(logger))

    if cwd is not None and not os.path.isdir(cwd):
        os.makedirs(cwd) # this throws exception if fails

    cmd = quote_command(cmd) # to prevent _popen() bug
    p = subprocess.Popen(cmd, cwd=cwd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    if log_command:
        mylogger("Running: %s" % cmd)
    while True:
        line=""
        try:
            line = p.stdout.readline()
            line = line.decode(encoding)
        except Exception:
            type, e, tb = sys.exc_info()
            logging.error(e)
            logging.error("The output of the command could not be decoded as %s\ncmd: %s\n line ignored: %s" %\
                (encoding, cmd, repr(line)))
            pass

        output.append(line)
        if not line:
            break
        line = line.rstrip('\n\r')
        mylogger(line) # they are added by logging anyway
        if stdout :
            print(line)
    returncode = p.wait()
    if log_command :
        if timing:
            def secondsToStr(t):
                return "%02d:%02d:%02d" % functools.reduce(lambda ll,b : divmod(ll[0],b) + ll[1:], [(t*1000,),1000,60,60])[:3]
            mylogger("Returned: %d (execution time %s)\n" % (returncode, secondsToStr(time.clock()-t)))
        else:
            mylogger("Returned: %d\n" % returncode)

    if not returncode == 0: # running a tool that returns non-zero? this deserves a warning
        logging.warning("Returned: %d from: %s\nOutput %s" % (returncode, cmd, '\n'.join(output)))

    return returncode, output

def system(cmd, cwd=None, logger=None, stdout=None, log_command=_sentinel, timing=_sentinel):
    """ This works similar to :py:func:`os.system` but add some useful optional parameters.

    * ``cmd`` - command to be executed
    * ``cwd`` - optional working directory to be set before running cmd
    * ``logger`` - None, a filename, handle or a function like print or :py:meth:`logging.Logger.warning`
    
    Returns the exit code reported by the execution of the command, 0 means success.

    >>> import os, logging
    ... import tendo.tee
    ... tee.system("echo test", logger=logging.error)  # output using python logging
    ... tee.system("echo test", logger="log.txt")  # output to a file
    ... f = open("log.txt", "w")
    ... tee.system("echo test", logger=f) # output to a filehandle
    ... tee.system("echo test", logger=print) # use the print() function for output
    """
    (returncode, output) = system2(cmd, cwd=cwd, logger=logger, stdout=stdout, log_command=log_command, timing=timing)
    return returncode

class testTee(unittest.TestCase):
    def test_1(self):
        """

                               CMD      os.system()
           1  sort /?             ok          ok
           2  "sort" /?           ok          ok
           3  sort "/?"           ok          ok
           4  "sort" "/?"         ok         [bad]
           5  ""sort /?""         ok          [bad]
           6  "sort /?"          [bad]         ok
           7  "sort "/?""        [bad]         ok
           8 ""sort" "/?""       [bad]           ok

"""

        quotes = {
            'dir >nul': 'dir >nul',
            'cd /D "C:\\Program Files\\"':'"cd /D "C:\\Program Files\\""',
            'python -c "import os" dummy':'"python -c "import os" dummy"',
            'sort':'sort',
        }

        # we fake the os name because we want to run the test on any platform
        save = os.name
        os.name = 'nt'

        for key, value in quotes.items():
            resulted_value = quote_command(key)
            self.assertEqual(value, resulted_value, "Returned <%s>, expected <%s>" % (resulted_value, value))
            #ret = os.system(resulted_value)
            #if not ret==0:
            #    print("failed")
        os.name = save

if __name__ == '__main__':
    import os
    unittest.main()
    """
    import colorer
    import tempfile, os

    logging.basicConfig(level=logging.NOTSET,
        format='%(message)s')

    # default (stdout)
    print("#1")
    system("python --version")

    # function/method
    print("#2")
    system("python --version", logger=logging.error)

    # function (this is the same as default)
    print("#3")
    system("python --version", logger=print)

    # handler
    print("#4")
    f = tempfile.NamedTemporaryFile()
    system("python --version", logger=f)
    f.close()

    # test with string (filename)
    print("#5")
    (f, fname) = tempfile.mkstemp()
    system("python --version", logger=fname)
    os.close(f)
    os.unlink(fname)

    print("#6")
    stdout = False
    logger = None
    system("echo test")

    print("#7")
    stdout = True
    system("echo test2")

"""


#!/usr/bin/env python
# Setuptools is required for the use_2to3 option below. You should install it
# from the Distribute home page, http://packages.python.org/distribute/
import sys
from setuptools import setup, Command
from setuptools.command.test import test as TestCommand

#from distutils.core import setup, Command

from tendo import __version__

# Hack to prevent stupid "TypeError: 'NoneType' object is not callable" error
# in multiprocessing/util.py _exit_function when running `python
# setup.py test` (see
# http://www.eby-sarna.com/pipermail/peak/2010-May/003357.html)
try:
    import multiprocessing
except ImportError:
    pass

test_requirements=['pep8>=0.6','nose','six','sphinx','pytest-xdist'] #'nosexcover']
test_suite="py.test"
#if sys.hexversion >= 0x02060000:
#    requirements.extend(['nose-machineout'])
#    test_suite="py.test"

# handle python 3
if sys.version_info >= (3,):
    use_2to3 = True
else:
    use_2to3 = False

options = {}

#class PyTest(Command):
#    user_options = []
#    def initialize_options(self):
#        pass
#    def finalize_options(self):
#        pass
#    def run(self):
#        import sys,subprocess
#        errno = subprocess.call([sys.executable, 'tox'])
#        raise SystemExit(errno)

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True
    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        pytest.main(self.test_args)


setup(
	name = 'tendo',
	py_modules = ['tendo.colorer', 'tendo.execfile2', 'tendo.singleton', 'tendo.tee', 'tendo.unicode'],
	version = __version__,
	zip_safe = False,
	description = 'A Python library that extends some core functionality',
	author = 'Sorin Sbarnea',
	author_email = 'sorin.sbarnea@gmail.com',
	url = 'https://github.com/ssbarnea/tendo',
	download_url = 'https://github.com/ssbarnea/tendo/archives/master',
	keywords = ['tendo', 'tee', 'unicode', 'colorer', 'singleton'],
	classifiers = [
		'Programming Language :: Python',
		'Programming Language :: Python :: 2.5',
		'Programming Language :: Python :: 2.6',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Development Status :: 4 - Beta',
		'Environment :: Other Environment',
		'Intended Audience :: Developers',
		'License :: OSI Approved :: BSD License',
        'License :: OSI Approved :: BSD License',
		'Operating System :: OS Independent',
		'Topic :: Software Development :: Libraries :: Python Modules',
		'Topic :: Internet',
	],
	long_description = open('README.txt').read(),
	setup_requires=['six'], #,'nosexcover'],
	tests_require=test_requirements, # autopep8 removed because it does not install on python2.5
	test_suite=test_suite,
	cmdclass={'test':PyTest},
#	use_2to3 = use_2to3,
        **options
)
